import re
import shlex
import sys
from collections import defaultdict
from six.moves.configparser import RawConfigParser


class RawCaseSensitiveConfigParser(RawConfigParser):
    optionxform = str


def get_interpretation_by_name(settings, prefix, interpret_setting):
    interpretation_by_name = defaultdict(dict)
    pattern_key = re.compile(prefix.replace('.', r'\.') + r'(.*)\.(.*)')
    for key, value in settings.items():
        try:
            name, attribute = pattern_key.match(key).groups()
        except AttributeError:
            continue
        interpretation = interpretation_by_name[name]
        interpretation.update(interpret_setting(attribute, value))
    return interpretation_by_name


def unicode_safely(x):
    # http://stackoverflow.com/a/23085282/192092
    if not hasattr(x, 'decode'):
        return x
    return x.decode(sys.getfilesystemencoding())


def split_arguments(x):
    try:
        return shlex.split(x)
    except UnicodeEncodeError:
        return shlex.split(x.encode('utf-8'))



from os.path import abspath, dirname, join
from setuptools import find_packages, setup


FOLDER = dirname(abspath(__file__))
DESCRIPTION = '\n\n'.join(open(join(FOLDER, x)).read().strip() for x in [
    'README.rst', 'CHANGES.rst'])
setup(
    name='invisibleroads-macros',
    version='0.6.9.1',
    description='Shortcut functions',
    long_description=DESCRIPTION,
    classifiers=[
        'Programming Language :: Python',
        'License :: OSI Approved :: MIT License',
    ],
    author='Roy Hyunjin Han',
    author_email='rhh@crosscompute.com',
    url='http://invisibleroads.com',
    keywords='invisibleroads',
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    setup_requires=[
        'pytest-runner',
    ],
    install_requires=[
        'pathlib',
        'python-dateutil',
        'six',
    ],
    tests_require=[
        'pytest',
    ])



from dateutil.parser import parse as parse_date


def parse_date_safely(x):
    x = str(x)
    try:
        return parse_date(x)
    except ValueError:
        # http://stackoverflow.com/questions/14595401
        return parse_date(x + '-01-01')
